@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/kinesisvideo/KinesisVideo_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kinesisvideo/KinesisVideo_EXPORTS.h>
 
-namespace Aws
-{
-namespace KinesisVideo
-{
-namespace Model
-{
-  enum class ComparisonOperator
-  {
-    NOT_SET,
-    BEGINS_WITH
-  };
+namespace Aws {
+namespace KinesisVideo {
+namespace Model {
+enum class ComparisonOperator { NOT_SET, BEGINS_WITH };
 
-namespace ComparisonOperatorMapper
-{
+namespace ComparisonOperatorMapper {
 AWS_KINESISVIDEO_API ComparisonOperator GetComparisonOperatorForName(const Aws::String& name);
 
 AWS_KINESISVIDEO_API Aws::String GetNameForComparisonOperator(ComparisonOperator value);
-} // namespace ComparisonOperatorMapper
-} // namespace Model
-} // namespace KinesisVideo
-} // namespace Aws
+}  // namespace ComparisonOperatorMapper
+}  // namespace Model
+}  // namespace KinesisVideo
+}  // namespace Aws
